#region Header
// Revit API .NET Labs
//
// Copyright (C) 2007-2009 by Autodesk, Inc.
//
// Permission to use, copy, modify, and distribute this software
// for any purpose and without fee is hereby granted, provided
// that the above copyright notice appears in all copies and
// that both that copyright notice and the limited warranty and
// restricted rights notice below appear in all supporting
// documentation.
//
// AUTODESK PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS.
// AUTODESK SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF
// MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE.  AUTODESK, INC.
// DOES NOT WARRANT THAT THE OPERATION OF THE PROGRAM WILL BE
// UNINTERRUPTED OR ERROR FREE.
//
// Use, duplication, or disclosure by the U.S. Government is subject to
// restrictions set forth in FAR 52.227-19 (Commercial Computer
// Software - Restricted Rights) and DFAR 252.227-7013(c)(1)(ii)
// (Rights in Technical Data and Computer Software), as applicable.
#endregion // Header

#region Namespaces
using System;
using System.IO;
using System.Collections;
using System.Collections.Generic;
using WinForms = System.Windows.Forms;
using Autodesk.Revit;
using Autodesk.Revit.Elements;
using Autodesk.Revit.Symbols;
using Autodesk.Revit.Events;
using System.Diagnostics;
#endregion // Namespaces

namespace Labs
{
  #region Lab_6_Event
  // Subscribe to, handle, and unsubscribe from document saving event.
  public class Lab_Event_PreventSave : IExternalApplication
  {    
    public IExternalApplication.Result OnStartup(ControlledApplication application)
    {
      try
      {
        // use the += operator to subscribe to DocumentSaving event. It is the same for other events
        application.DocumentSaving += new EventHandler<DocumentSavingEventArgs>(app_eventsHandlerMethod);         
      }
      catch (Exception ex)
      {
        WinForms.MessageBox.Show(ex.Message);
        return IExternalApplication.Result.Failed;
      }

      return IExternalApplication.Result.Succeeded;
    }
    public IExternalApplication.Result OnShutdown(ControlledApplication application)
    {
      // remove the event subscription using -= operateor.
      application.DocumentSaving -= new EventHandler<DocumentSavingEventArgs>(app_eventsHandlerMethod);    
      return IExternalApplication.Result.Succeeded;
    }

    // Shows a message to decide if save the document.
    public void app_eventsHandlerMethod(Object obj, DocumentSavingEventArgs args)
    {
      if (args.Cancellable)
      {
        // Ask whether to prevent from saving.
        WinForms.DialogResult dr = WinForms.MessageBox.Show(
          "Saving events handler was triggered. Using the pre-event mechanism , we have a chance to prevent it happening.\r\n  Continue to save the document?",
          "Event document saving", 
          WinForms.MessageBoxButtons.YesNo, 
          WinForms.MessageBoxIcon.Question );

        args.Cancel = (dr != WinForms.DialogResult.Yes);
      }
    }
  }
  #endregion Lab_6_Event
}
